==> itc-foundation-0.1.5.tgz: package/src/tree.js <==
import {Component} from './components';

class Tree extends Component {

  /**
   * Return configuration defaults
   * @param void
   * @return {Object}
   */
  defaults () {
    return {
      data: {},
      cache: new Map(),
      delimiter: '/',
      tokenize: (expr, delim) => expr.split(delim),
      normalize: (expr, delim) => expr[0] === delim ? expr.slice(1) : expr,
    };
  }

  /**
   * @param {Object} options
   * @param {Object} options.tree - tree data
   * @param {Object} options.cache - object that implements get(), set() and has()
   * @param {Function} options.tokenize - path expresssion tokenizer
   */
  constructor (options={}) {
    super(options);
    this.data = this.option('data', {pull: true});
  }

  /**
   * Tokenize the given expression on '.' and traverse the translation tree
   * until a match is found. If no match is found, return an empty string.
   * This is the main
   * @param {String} expr
   * @return {mixed}
   */
  path (expr) {
    let {cache, normalize, tokenize, delimiter} = this.options;

    expr = normalize(expr, delimiter);

    if (cache.has(expr)) {
      return cache.get(expr);
    }

    let traverse = (tree, token) => {
      if (tree && tree.hasOwnProperty(token)) {
        return tree[token];
      }
      throw new Error(`failed to resolve path expression "${expr}"`);
    };

    let value = tokenize(expr, delimiter).reduce(traverse, this.data);

    cache.set(expr, value);

    return value;
  }

}

export default {Tree};

==> itc-foundation-0.3.0.tgz: package/src/tree.js <==
import {Component} from './components';
import cache from './cache';

class Tree extends Component {

  /**
   * @inheritdoc
   */
  defaults () {
    return {
      data: {},
      cache: cache.dummy(),
      delimiter: '/',
      tokenize: (expr, delim) => expr.split(delim),
      normalize: (expr, delim) => expr[0] === delim ? expr.slice(1) : expr,
    };
  }

  /**
   * @param {Object} options
   * @param {Object} options.data - tree data
   * @param {Object} options.cache - object that implements get(), set() and has()
   * @param {String} options.delimiter - token boundary
   * @param {Function} options.tokenize - path expression tokenizer
   * @param {Function} options.normalize - path expression normalizer
   */
  constructor (options={}) {
    super(options);
    this.data = this.option('data', {pull: true});
  }

  /**
   * Tokenize the given expression on '.' and traverse the translation tree
   * until a match is found. If no match is found, return an empty string.
   * This is the main
   * @param {String} expr
   * @return {mixed}
   */
  path (expr) {
    let {cache, normalize, tokenize, delimiter} = this.options;

    expr = normalize(expr, delimiter);

    if (cache.has(expr)) {
      return cache.get(expr);
    }

    let traverse = (tree, token) => {
      if (tree && tree.hasOwnProperty(token)) {
        return tree[token];
      }
      throw new Error(`failed to resolve path expression "${expr}"`);
    };

    let tokens = tokenize(expr, delimiter);
    let value = tokens.reduce(traverse, this.data);

    cache.set(expr, value);

    return value;
  }

}

export default {Tree};
